import os
import sys
import time
import warnings
warnings.filterwarnings("ignore")
from tensorflow.core.protobuf.config_pb2 import ConfigProto
from tensorflow.python.client.session import InteractiveSession
from config.config import Config
from data.data import get_single_data
from ensemble1.ensemble_model_keras import StackingModel
from tools.tools import get_label, score2, set_global_determinism

os.environ['TF_XLA_FLAGS'] = '--tf_xla_enable_xla_devices'


config1 = ConfigProto()
config1.gpu_options.allow_growth = True
session = InteractiveSession(config=config1)

if __name__ == "__main__":
    sys.setrecursionlimit(15000)
    start = time.time()
    SEED = 0
    set_global_determinism(SEED)

    # datasets = {
    #     "6mA": ["6mA_R.chinensis","6mA_A.thaliana", "6mA_C.elegans", "6mA_C.equisetifolia",
    #             "6mA_D.melanogaster", "6mA_F.vesca","6mA_H.sapiens", "6mA_S.cerevisiae",
    #             "6mA_T.thermophile","6mA_Tolypocladium", "6mA_Xoc BLS256"],
    #     "4mC":  [ "4mC_E.coli2","4mC_G.pickeringii2","4mC_G.subterraneus2","4mC_A.thaliana2",
    #               "4mC_C.elegans2","4mC_D.melanogaster2","4mC_C.equisetifolia", "4mC_F.vesca",
    #               "4mC_S.cerevisiae", "4mC_Tolypocladium","4mC_E.coli", "4mC_G.pickeringii",
    #               "4mC_G.subterraneus","4mC_D.melanogaster","4mC_A.thaliana","4mC_C.elegans"],
    #     "5hmC": ["5hmC_H.sapiens", "5hmC_M.musculus"]
    # }

    config_global = Config()
    dataset = "4mC_C.equisetifolia"
    config_global.model_name = dataset
    config_global.model_save_path = "D:/temp/data/keras_4mC.hdf5"  # "data/global_pretrain_model_group1.model"
    # use feature selection or not
    config_global.is_feature_selection = True
    # use transfer learning or not
    config_global.load_global_pretrain_model = True
    config_global.global_model_save_path = "data/pretrain_model.h5"

    original_train1, original_test1 = get_single_data(dataset)  # DataFrame with 2 columns (label, seq)
    train_label1 = get_label(original_train1)
    test_label1 = get_label(original_test1)

    sm = StackingModel(config_global)
    sm.fit(original_train1, train_label1)
    pred_prob = sm.predict(original_test1)
    result_temp = score2(test_label1, pred_prob)
    print(dataset,result_temp)

    end = time.time()
    print("Time consuming:%.2f seconds" % (end - start))
